@@ -11,12 +11,12 @@ static R_CallMethodDef CallEntries[] = {
 	RegCallFun(R_curl_easy_init, 0),
 	RegCallFun(R_curl_easy_duphandle, 1),
 
-	RegCallFun(R_curl_easy_perform, 3),
-	RegCallFun(R_curl_easy_setopt, 4),
+	RegCallFun(R_curl_easy_perform, 4),
+	RegCallFun(R_curl_easy_setopt, 5),
 	RegCallFun(R_curl_easy_getinfo, 2),
 
 	RegCallFun(R_curl_escape, 2),
-	RegCallFun(R_post_form, 4),
+	RegCallFun(R_post_form, 5),
 
 	RegCallFun(R_getCURLErrorEnum, 0),
 	RegCallFun(R_getCURLInfoEnum, 0),
@@ -29,7 +29,7 @@ static R_CallMethodDef CallEntries[] = {
 void
 R_init_RCurl(DllInfo *dll)
 {
-    R_useDynamicSymbols(dll, FALSE);
+    R_useDynamicSymbols(dll, TRUE);
     R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
 }
 
